<?php
/**
 *	@package		SendInBlue
 *	@subpackage		view.html.php
 *	@version		1.0.0
 *
 *	@author			Branislav Gligorov <branislav.gligorov@itsbg.eu>	
 *	@copyright		Copyright (C) 2018 SendInBlue, All Rights Reserved
 *	@license		GNU/GPL Version 2 or later - http://www.gnu.org/licenses/gpl-2.0.html
 */


// No direct access to this file
defined('_JEXEC') or die('Restricted access'); 

/**
 * Sendinblue View class for the Smtpsettings
 */
class SendinblueViewSmtpsettings extends JViewLegacy
{
	// Overwriting JView display method
	function display($tpl = null)
	{
		// get component params
		$this->params = JComponentHelper::getParams('com_sendinblue');
		// get the application
		$this->app = JFactory::getApplication();
		// get the user object
		$this->user = JFactory::getUser();
		// get global action permissions
		$this->canDo = SendinblueHelper::getActions('smtpsettings');
		// Initialise variables.
		$this->item = $this->get('Item');
		// Custom Script (JViewLegacy display) *
		$app   = \JFactory::getApplication();
				$this->sibjapi = new SibJapi(true, true); 
				if ($this->sibjapi->accountDetails === null || $this->sibjapi->accountDetails === false) {
		foreach ($this->sibjapi->errors as $key => $value) { $app->enqueueMessage($value, 'error'); }
					// show additiona error message in view based on the object state
				} else { // compare setting
					$this->SMTPset = SibJapiHelper::checkJmail($this->sibjapi->accountDetails->data);
				}
				$this->simulatesmtpnotactive = $this->params->get('simulatesmtpnotactive', null);
		

		// We don't need toolbar in the modal window.
		if ($this->getLayout() !== 'modal')
		{
			// add the tool bar
			$this->addToolBar();
		}

		// set the document
		$this->setDocument();

		// Check for errors.
		if (count($errors = $this->get('Errors')))
		{
			throw new Exception(implode("\n", $errors), 500);
		}

		parent::display($tpl);
	}

	/**
	 * Prepares the document
	 */
	protected function setDocument()
	{

		// always make sure jquery is loaded.
		JHtml::_('jquery.framework');
		// Load the header checker class.
		require_once( JPATH_COMPONENT_ADMINISTRATOR.'/helpers/headercheck.php' );
		// Initialize the header checker.
		$HeaderCheck = new sendinblueHeaderCheck;
		// Add PHP (custom document script) 
				// set buttons to remove under specific conditions - button are set buy method names defined under custom buttons
				if ($this->sibjapi->settings === false) {
					$removebuttons = array( 'saveSmtp', 'sendTestemail', 'restoreSmtp' ); 
				} else {
					if ($this->sibjapi->accountDetails === false) {
						$removebuttons = array( 'saveSmtp', 'sendTestemail', 'restoreSmtp' );
					} else {
						$ad = $this->sibjapi->accountDetails->data;
						if ($this->simulatesmtpnotactive || !isset($ad->relay->enabled) || ( isset($ad->relay->enabled) && $ad->relay->enabled != true)) {
							$removebuttons = array( 'saveSmtp', 'sendTestemail', 'restoreSmtp' );
						} else {
							if ($this->SMTPset == false) {
								$removebuttons = array( 'sendTestemail', 'restoreSmtp' );	
							} else {
								// all buttons stays
							}
						} 
					}
				}
				if (count($removebuttons)) {
					foreach ($removebuttons as $item) {
						$js .= "if ( $( this ).attr('onclick').indexOf('" . $item . "') >= 0  ) { $( this ).closest('div').remove(); }";
					}			
					$js = "
						jQuery( document ).ready(function($) {
							$('button').each(function( index ) {"
							. $js .	"
							});
						});
					";
					$this->document->addScriptDeclaration($js);
				}
		
		
		// add the document default css file
		$this->document->addStyleSheet(JURI::root(true) .'/administrator/components/com_sendinblue/assets/css/smtpsettings.css', (SendinblueHelper::jVersion()->isCompatible('3.8.0')) ? array('version' => 'auto') : 'text/css');
		// Set the Custom JS script to view
		$this->document->addScriptDeclaration("
			jQuery( document ).ready(function($) {
				$('#adminForm').remove();
				$('#adminFormREPLACEMENT').attr('id', 'adminForm');
			});
			
		");
	}

	/**
	 * Setting the toolbar
	 */
	protected function addToolBar()
	{
		// hide the main menu
		$this->app->input->set('hidemainmenu', true);
		// set the title
		if (isset($this->item->name) && $this->item->name)
		{
			$title = $this->item->name;
		}
		// Check for empty title and add view name if param is set
		if (empty($title))
		{
			$title = JText::_('COM_SENDINBLUE_SMTPSETTINGS');
		}
		// add title to the page
		JToolbarHelper::title($title,'envelope');
		// add the back button
		// JToolBarHelper::custom('smtpsettings.back', 'undo-2', '', 'COM_SENDINBLUE_BACK', false);
		// add cpanel button
		JToolBarHelper::custom('smtpsettings.dashboard', 'grid-2', '', 'COM_SENDINBLUE_DASH', false);
		if ($this->canDo->get('smtpsettings.set_joomla_mail_settings'))
		{
			// add Set Joomla mail settings button.
			JToolBarHelper::custom('smtpsettings.saveSmtp', 'pencil', '', 'COM_SENDINBLUE_SET_JOOMLA_MAIL_SETTINGS', false);
		}
		if ($this->canDo->get('smtpsettings.send_test_email'))
		{
			// add Send test email button.
			JToolBarHelper::custom('smtpsettings.sendTestemail', 'envelope', '', 'COM_SENDINBLUE_SEND_TEST_EMAIL', false);
		}
		if ($this->canDo->get('smtpsettings.restore_smpt_settings'))
		{
			// add Restore SMPT settings button.
			JToolBarHelper::custom('smtpsettings.restoreSmtp', 'undo', '', 'COM_SENDINBLUE_RESTORE_SMPT_SETTINGS', false);
		}

		// set help url for this view if found
		$help_url = SendinblueHelper::getHelpUrl('smtpsettings');
		if (SendinblueHelper::checkString($help_url))
		{
			JToolbarHelper::help('COM_SENDINBLUE_HELP_MANAGER', false, $help_url);
		}

		// add the options comp button
		if ($this->canDo->get('core.admin') || $this->canDo->get('core.options'))
		{
			JToolBarHelper::preferences('com_sendinblue');
		}
	}

	/**
	 * Escapes a value for output in a view script.
	 *
	 * @param   mixed  $var  The output to escape.
	 *
	 * @return  mixed  The escaped value.
	 */
	public function escape($var)
	{
		// use the helper htmlEscape method instead.
		return SendinblueHelper::htmlEscape($var, $this->_charset);
	}
}
?>
