<?php
/**
 *	@package		SendInBlue
 *	@subpackage		subscription.php
 *	@version		1.0.0
 *
 *	@author			Branislav Gligorov <branislav.gligorov@itsbg.eu>	
 *	@copyright		Copyright (C) 2018 SendInBlue, All Rights Reserved
 *	@license		GNU/GPL Version 2 or later - http://www.gnu.org/licenses/gpl-2.0.html
 */


// No direct access to this file
defined('_JEXEC') or die('Restricted access');

/**
 * Sendinblue Subscription Model
 */
class SendinblueModelSubscription extends JModelItem
{
	/**
	 * Model context string.
	 *
	 * @var        string
	 */
	protected $_context = 'com_sendinblue.subscription';

	/**
	 * Model user data.
	 *
	 * @var        strings
	 */
	protected $user;
	protected $userId;
	protected $guest;
	protected $groups;
	protected $levels;
	protected $app;
	protected $input;
	protected $uikitComp;

	/**
	 * @var object item
	 */
	protected $item;

	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @since   1.6
	 *
	 * @return void
	 */
	protected function populateState()
	{
		$this->app = JFactory::getApplication();
		$this->input = $this->app->input;
		// Get the itme main id
		$id = $this->input->getInt('id', null);
		$this->setState('subscription.id', $id);

		// Load the parameters.
		$params = $this->app->getParams();
		$this->setState('params', $params);
		parent::populateState();
	}

	/**
	 * Method to get article data.
	 *
	 * @param   integer  $pk  The id of the article.
	 *
	 * @return  mixed  Menu item data object on success, false on failure.
	 */
	public function getItem($pk = null)
	{
		$this->user = JFactory::getUser();
		// check if this user has permission to access item
		if (!$this->user->authorise('site.subscription.access', 'com_sendinblue'))
		{
			$app = JFactory::getApplication();
			$app->enqueueMessage(JText::_('COM_SENDINBLUE_NOT_AUTHORISED_TO_VIEW_SUBSCRIPTION'), 'error');
			// redirect away to the home page if no access allowed.
			$app->redirect(JURI::root());
			return false;
		}
		$this->userId = $this->user->get('id');
		$this->guest = $this->user->get('guest');
		$this->groups = $this->user->get('groups');
		$this->authorisedGroups = $this->user->getAuthorisedGroups();
		$this->levels = $this->user->getAuthorisedViewLevels();
		$this->initSet = true;

		$pk = (!empty($pk)) ? $pk : (int) $this->getState('subscription.id');
		
		if ($this->_item === null)
		{
			$this->_item = array();
		}

		if (!isset($this->_item[$pk]))
		{
			try
			{
				// Get a db connection.
				$db = JFactory::getDbo();

				// Create a new query object.
				$query = $db->getQuery(true);

				// Get from #__sendinblue_subscription_form as a
				$query->select($db->quoteName(
			array('a.id','a.asset_id','a.subscriptionformid','a.siblists','a.title','a.confirmationtype','a.optintmplid','a.finalconfirmation','a.finalfollowuptmplid','a.followuptmplid','a.confirmationpage','a.confirmationpagecustom','a.subsformmsgemptyfield','a.subsformmsgsuccess','a.subsformmsguserexist','a.subsformmsguserinfoinvalid','a.subsformmsgerror','a.blocksubform','a.published','a.created_by','a.modified_by','a.created','a.modified','a.version','a.hits','a.ordering'),
			array('id','asset_id','subscriptionformid','siblists','title','confirmationtype','optintmplid','finalconfirmation','finalfollowuptmplid','followuptmplid','confirmationpage','confirmationpagecustom','subsformmsgemptyfield','subsformmsgsuccess','subsformmsguserexist','subsformmsguserinfoinvalid','subsformmsgerror','blocksubform','published','created_by','modified_by','created','modified','version','hits','ordering')));
				$query->from($db->quoteName('#__sendinblue_subscription_form', 'a'));
				$query->where('a.id = ' . (int) $pk);

				// Reset the query using our newly populated query object.
				$db->setQuery($query);
				// Load the results as a stdClass object.
				$data = $db->loadObject();

				if (empty($data))
				{
					$app = JFactory::getApplication();
					// If no data is found redirect to default page and show warning.
					$app->enqueueMessage(JText::_('COM_SENDINBLUE_NOT_FOUND_OR_ACCESS_DENIED'), 'warning');
					$app->redirect(JURI::root());
					return false;
				}
				// Check if we can decode siblists
				if (SendinblueHelper::checkJson($data->siblists))
				{
					// Decode siblists
					$data->siblists = json_decode($data->siblists, true);
				}
				// Check if we can decode blocksubform
				if (SendinblueHelper::checkJson($data->blocksubform))
				{
					// Decode blocksubform
					$data->blocksubform = json_decode($data->blocksubform, true);
				}

				// set data object to item.
				$this->_item[$pk] = $data;
			}
			catch (Exception $e)
			{
				if ($e->getCode() == 404)
				{
					// Need to go thru the error handler to allow Redirect to work.
					JError::raiseWaring(404, $e->getMessage());
				}
				else
				{
					$this->setError($e);
					$this->_item[$pk] = false;
				}
			}
		}

		return $this->_item[$pk];
	}

function subscribe() {}
}
